// File: controls.cpp
// Purpose: Header file for controls.cpp
// 2015-09 jan@breem.nl

#ifndef CONTROLS_H
#define CONTROLS_H

#include <arduino.h>

/*
How to use these controls.

Calling one of these functions draws the control on the specified location and 
-when specified- enters the touch sensitive area and a pointer to a function into the TouchList.
The pointer points to the function you want to have called when the associated area is touched. 
Such functions must be void, they cannot accept or return any value. 
(C/CPP does allow function pointers to non-void functions, but it is not supported here)  

Set the "#define NUMBEROFTOUCHAREAS in LibTFT2p8.h" to the largest number of touch areas you want to use in any screen layout.

Set the boolean "EnterInTouchList" to true only for the first time you draw a control. If a control has to be redrawn
  with only different color(s) set "EnterInTouchList" to false to prevent a new entry into the TouchList.
If you need to change the position or the associated callback function for any control then you need to 
  use "ClearScreen()" and redraw the whole screen. "ClearScreen()" also clears the TouchList
 
Put a statement like "int dummy = tft_DetectTouch();" in the "loop" of your .ino file. This calls the callback function.  
Take care that "tft_DetectTouch()" is not called to often, this will result in multiple calls during one touch.
You may need a time-out mechanism to prevent such multiple callback's. This library does not provide such. 
A "delay(some_time);" in your "loop" may do the job.  

The example projects demonstrate the use of certain subsets of these controls.

Feel free to modify this library for your needs, create more controls etc..

This library is intended to work in conjunction with the files
LibTFT2p8.cpp, LibTFT2p8.h, Simplefont.h, TFTv2.cpp, TFTv2.h, controls.cpp.
Put all these files in your project directory 
DO NOT put them in your ..../Arduino/libraries/  directory, that will not work.
The files SeeedTouchScreen.cpp and SeeedTouchScreen.h should be in a directory under ..../Arduino/libraries/ 

This library is published without any guarantee for proper operation or absence of side-effects.
*/

enum t_RecordType {LP = 1, EP, SI};  // For project TangentPlayer

void StoreTouch (int X, int Y, void (*CallBackPtr) (void));
void ClearScreen (void);
void DrawButtPlus (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtMinus (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtOn (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtOff (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtTimer (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtPlay (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtPause (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtStop (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtForward (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtReverse (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtBack (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtZ (int X, int Y, int Color, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtRD (int X, int Y, int Color, bool R, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawButtRecordType (int X, int Y, t_RecordType RecordType, bool Enabled, void (*CallBackPtr) (void), bool EnterInTouchList);
void DrawLed (int X, int Y, byte diam, bool on, int Color);
void UpdateVUmeter (byte Left, byte Right);
void InitVUmeter (void);

#endif // CONTROLS_H


